# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.print_feedback import PrintFeedback  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintFeedback(unittest.TestCase):
    """PrintFeedback unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintFeedback
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.print_feedback.PrintFeedback()  # noqa: E501
        if include_optional :
            return PrintFeedback(
                feedback_rating = 1.337, 
                feedback_message = '0'
            )
        else :
            return PrintFeedback(
        )

    def testPrintFeedback(self):
        """Test PrintFeedback"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.prints_response import PrintsResponse  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintsResponse(unittest.TestCase):
    """PrintsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.prints_response.PrintsResponse()  # noqa: E501
        if include_optional :
            return PrintsResponse(
                prints = [
                    carbon3d.models.print.Print(
                        name = '0', 
                        print_id = '0', 
                        build_uuid = '0', 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        remaining_sec = 56, 
                        printed_by = '0', 
                        print_order_uuid = '0', 
                        print_order_number = '0', 
                        status = '0', 
                        origin = carbon3d.models.print_origin.Print_origin(
                            cassette_serial = '0', 
                            cassette_nfc_uid = '0', 
                            platform_serial = '0', 
                            platform_nfc_uid = '0', 
                            printer_serial = '0', 
                            software_version = '0', ), 
                        config = carbon3d.models.print_config.Print_config(
                            resin_name = '0', 
                            print_profile = '0', 
                            release_film_nm = 56, 
                            slice_thickness_nm = 56, ), 
                        metrics = carbon3d.models.print_metrics.Print_metrics(
                            average_speed_mmhr = 56, 
                            consumed_resin_volume_ml = 1.337, 
                            minimum_required_resin_volume_ml = 1.337, 
                            estimated_total_resin_volume_ml = 1.337, 
                            measured_resin_volume_ml = 1.337, ), 
                        feedback = carbon3d.models.print_feedback.Print_feedback(
                            feedback_rating = 1.337, 
                            feedback_message = '0', ), )
                    ], 
                total_count = 56, 
                offset = 56, 
                limit = 56
            )
        else :
            return PrintsResponse(
        )

    def testPrintsResponse(self):
        """Test PrintsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrintedPartRef(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'part_uuid': 'str',
        'status': 'PrintedPartStatus'
    }

    attribute_map = {
        'uuid': 'uuid',
        'part_uuid': 'part_uuid',
        'status': 'status'
    }

    def __init__(self, uuid=None, part_uuid=None, status=None, local_vars_configuration=None):  # noqa: E501
        """PrintedPartRef - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._part_uuid = None
        self._status = None
        self.discriminator = None

        self.uuid = uuid
        self.part_uuid = part_uuid
        self.status = status

    @property
    def uuid(self):
        """Gets the uuid of this PrintedPartRef.  # noqa: E501

        Printed Part UUID  # noqa: E501

        :return: The uuid of this PrintedPartRef.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this PrintedPartRef.

        Printed Part UUID  # noqa: E501

        :param uuid: The uuid of this PrintedPartRef.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uuid is None:  # noqa: E501
            raise ValueError("Invalid value for `uuid`, must not be `None`")  # noqa: E501

        self._uuid = uuid

    @property
    def part_uuid(self):
        """Gets the part_uuid of this PrintedPartRef.  # noqa: E501

        Part UUID  # noqa: E501

        :return: The part_uuid of this PrintedPartRef.  # noqa: E501
        :rtype: str
        """
        return self._part_uuid

    @part_uuid.setter
    def part_uuid(self, part_uuid):
        """Sets the part_uuid of this PrintedPartRef.

        Part UUID  # noqa: E501

        :param part_uuid: The part_uuid of this PrintedPartRef.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and part_uuid is None:  # noqa: E501
            raise ValueError("Invalid value for `part_uuid`, must not be `None`")  # noqa: E501

        self._part_uuid = part_uuid

    @property
    def status(self):
        """Gets the status of this PrintedPartRef.  # noqa: E501


        :return: The status of this PrintedPartRef.  # noqa: E501
        :rtype: PrintedPartStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PrintedPartRef.


        :param status: The status of this PrintedPartRef.  # noqa: E501
        :type: PrintedPartStatus
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintedPartRef):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintedPartRef):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.printed_parts_response import PrintedPartsResponse  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintedPartsResponse(unittest.TestCase):
    """PrintedPartsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintedPartsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.printed_parts_response.PrintedPartsResponse()  # noqa: E501
        if include_optional :
            return PrintedPartsResponse(
                limit = 56, 
                offset = 56, 
                total_count = 56, 
                parts = [
                    {"build_uuid":"d938c229-a14d-4314-8a00-f2d2717c43d0","model_uuid":"26ee9a9b-0a23-4146-93de-27afea4acd65","part_number":"101000-01","part_order_number":"","part_order_uuid":"7eacc87e-e4ee-4911-b317-039717dd9a76","part_uuid":"4133bbe6-4858-4f18-ad6f-95ef6ea08b31","print_id":"KT310GVA","print_order_number":"WO-123","print_order_uuid":"657208d6-d796-4623-8981-d7aa66932a69","serial_number":"KT310GVA-1","status":"complete","tags":{"part_number":{"size":"large","color":"red"},"part":{"customization_id":"123456"},"printed_part":{}},"uuid":"cc49c64d-c3cf-45f8-943b-c8693f28c146"}
                    ]
            )
        else :
            return PrintedPartsResponse(
        )

    def testPrintedPartsResponse(self):
        """Test PrintedPartsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrintedPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'part_uuid': 'str',
        'model_uuid': 'str',
        'part_number': 'str',
        'build_uuid': 'str',
        'part_order_uuid': 'str',
        'part_order_number': 'str',
        'print_order_uuid': 'str',
        'print_order_number': 'str',
        'print_id': 'str',
        'serial_number': 'str',
        'tags': 'PrintedPartTags',
        'status': 'PrintedPartStatus',
        'genealogy': 'PartGenealogy',
        'error': 'str'
    }

    attribute_map = {
        'uuid': 'uuid',
        'part_uuid': 'part_uuid',
        'model_uuid': 'model_uuid',
        'part_number': 'part_number',
        'build_uuid': 'build_uuid',
        'part_order_uuid': 'part_order_uuid',
        'part_order_number': 'part_order_number',
        'print_order_uuid': 'print_order_uuid',
        'print_order_number': 'print_order_number',
        'print_id': 'print_id',
        'serial_number': 'serial_number',
        'tags': 'tags',
        'status': 'status',
        'genealogy': 'genealogy',
        'error': 'error'
    }

    def __init__(self, uuid=None, part_uuid=None, model_uuid=None, part_number=None, build_uuid=None, part_order_uuid=None, part_order_number=None, print_order_uuid=None, print_order_number=None, print_id=None, serial_number=None, tags=None, status=None, genealogy=None, error=None, local_vars_configuration=None):  # noqa: E501
        """PrintedPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._part_uuid = None
        self._model_uuid = None
        self._part_number = None
        self._build_uuid = None
        self._part_order_uuid = None
        self._part_order_number = None
        self._print_order_uuid = None
        self._print_order_number = None
        self._print_id = None
        self._serial_number = None
        self._tags = None
        self._status = None
        self._genealogy = None
        self._error = None
        self.discriminator = None

        self.uuid = uuid
        self.part_uuid = part_uuid
        if model_uuid is not None:
            self.model_uuid = model_uuid
        if part_number is not None:
            self.part_number = part_number
        if build_uuid is not None:
            self.build_uuid = build_uuid
        if part_order_uuid is not None:
            self.part_order_uuid = part_order_uuid
        if part_order_number is not None:
            self.part_order_number = part_order_number
        if print_order_uuid is not None:
            self.print_order_uuid = print_order_uuid
        if print_order_number is not None:
            self.print_order_number = print_order_number
        if print_id is not None:
            self.print_id = print_id
        if serial_number is not None:
            self.serial_number = serial_number
        if tags is not None:
            self.tags = tags
        self.status = status
        self.genealogy = genealogy
        if error is not None:
            self.error = error

    @property
    def uuid(self):
        """Gets the uuid of this PrintedPart.  # noqa: E501

        Printed Part UUID  # noqa: E501

        :return: The uuid of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this PrintedPart.

        Printed Part UUID  # noqa: E501

        :param uuid: The uuid of this PrintedPart.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uuid is None:  # noqa: E501
            raise ValueError("Invalid value for `uuid`, must not be `None`")  # noqa: E501

        self._uuid = uuid

    @property
    def part_uuid(self):
        """Gets the part_uuid of this PrintedPart.  # noqa: E501


        :return: The part_uuid of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._part_uuid

    @part_uuid.setter
    def part_uuid(self, part_uuid):
        """Sets the part_uuid of this PrintedPart.


        :param part_uuid: The part_uuid of this PrintedPart.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and part_uuid is None:  # noqa: E501
            raise ValueError("Invalid value for `part_uuid`, must not be `None`")  # noqa: E501

        self._part_uuid = part_uuid

    @property
    def model_uuid(self):
        """Gets the model_uuid of this PrintedPart.  # noqa: E501


        :return: The model_uuid of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._model_uuid

    @model_uuid.setter
    def model_uuid(self, model_uuid):
        """Sets the model_uuid of this PrintedPart.


        :param model_uuid: The model_uuid of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._model_uuid = model_uuid

    @property
    def part_number(self):
        """Gets the part_number of this PrintedPart.  # noqa: E501


        :return: The part_number of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this PrintedPart.


        :param part_number: The part_number of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    @property
    def build_uuid(self):
        """Gets the build_uuid of this PrintedPart.  # noqa: E501


        :return: The build_uuid of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._build_uuid

    @build_uuid.setter
    def build_uuid(self, build_uuid):
        """Sets the build_uuid of this PrintedPart.


        :param build_uuid: The build_uuid of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._build_uuid = build_uuid

    @property
    def part_order_uuid(self):
        """Gets the part_order_uuid of this PrintedPart.  # noqa: E501


        :return: The part_order_uuid of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._part_order_uuid

    @part_order_uuid.setter
    def part_order_uuid(self, part_order_uuid):
        """Sets the part_order_uuid of this PrintedPart.


        :param part_order_uuid: The part_order_uuid of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._part_order_uuid = part_order_uuid

    @property
    def part_order_number(self):
        """Gets the part_order_number of this PrintedPart.  # noqa: E501


        :return: The part_order_number of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._part_order_number

    @part_order_number.setter
    def part_order_number(self, part_order_number):
        """Sets the part_order_number of this PrintedPart.


        :param part_order_number: The part_order_number of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._part_order_number = part_order_number

    @property
    def print_order_uuid(self):
        """Gets the print_order_uuid of this PrintedPart.  # noqa: E501


        :return: The print_order_uuid of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._print_order_uuid

    @print_order_uuid.setter
    def print_order_uuid(self, print_order_uuid):
        """Sets the print_order_uuid of this PrintedPart.


        :param print_order_uuid: The print_order_uuid of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._print_order_uuid = print_order_uuid

    @property
    def print_order_number(self):
        """Gets the print_order_number of this PrintedPart.  # noqa: E501


        :return: The print_order_number of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._print_order_number

    @print_order_number.setter
    def print_order_number(self, print_order_number):
        """Sets the print_order_number of this PrintedPart.


        :param print_order_number: The print_order_number of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._print_order_number = print_order_number

    @property
    def print_id(self):
        """Gets the print_id of this PrintedPart.  # noqa: E501


        :return: The print_id of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._print_id

    @print_id.setter
    def print_id(self, print_id):
        """Sets the print_id of this PrintedPart.


        :param print_id: The print_id of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._print_id = print_id

    @property
    def serial_number(self):
        """Gets the serial_number of this PrintedPart.  # noqa: E501

        Only created after printing  # noqa: E501

        :return: The serial_number of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this PrintedPart.

        Only created after printing  # noqa: E501

        :param serial_number: The serial_number of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def tags(self):
        """Gets the tags of this PrintedPart.  # noqa: E501


        :return: The tags of this PrintedPart.  # noqa: E501
        :rtype: PrintedPartTags
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this PrintedPart.


        :param tags: The tags of this PrintedPart.  # noqa: E501
        :type: PrintedPartTags
        """

        self._tags = tags

    @property
    def status(self):
        """Gets the status of this PrintedPart.  # noqa: E501


        :return: The status of this PrintedPart.  # noqa: E501
        :rtype: PrintedPartStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PrintedPart.


        :param status: The status of this PrintedPart.  # noqa: E501
        :type: PrintedPartStatus
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def genealogy(self):
        """Gets the genealogy of this PrintedPart.  # noqa: E501


        :return: The genealogy of this PrintedPart.  # noqa: E501
        :rtype: PartGenealogy
        """
        return self._genealogy

    @genealogy.setter
    def genealogy(self, genealogy):
        """Sets the genealogy of this PrintedPart.


        :param genealogy: The genealogy of this PrintedPart.  # noqa: E501
        :type: PartGenealogy
        """

        self._genealogy = genealogy

    @property
    def error(self):
        """Gets the error of this PrintedPart.  # noqa: E501

        Error message (if part could not be produced)  # noqa: E501

        :return: The error of this PrintedPart.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this PrintedPart.

        Error message (if part could not be produced)  # noqa: E501

        :param error: The error of this PrintedPart.  # noqa: E501
        :type: str
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintedPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintedPart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PartGenealogyPrintInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'queued_at': 'datetime',
        'print_uuid': 'str',
        'printer_serial': 'str',
        'platform_serial': 'str',
        'cassette_serial': 'str',
        'resin_lot_number': 'str',
        'started_at': 'datetime',
        'finished_at': 'datetime',
        'error': 'str'
    }

    attribute_map = {
        'queued_at': 'queued_at',
        'print_uuid': 'print_uuid',
        'printer_serial': 'printer_serial',
        'platform_serial': 'platform_serial',
        'cassette_serial': 'cassette_serial',
        'resin_lot_number': 'resin_lot_number',
        'started_at': 'started_at',
        'finished_at': 'finished_at',
        'error': 'error'
    }

    def __init__(self, queued_at=None, print_uuid=None, printer_serial=None, platform_serial=None, cassette_serial=None, resin_lot_number=None, started_at=None, finished_at=None, error=None, local_vars_configuration=None):  # noqa: E501
        """PartGenealogyPrintInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._queued_at = None
        self._print_uuid = None
        self._printer_serial = None
        self._platform_serial = None
        self._cassette_serial = None
        self._resin_lot_number = None
        self._started_at = None
        self._finished_at = None
        self._error = None
        self.discriminator = None

        if queued_at is not None:
            self.queued_at = queued_at
        if print_uuid is not None:
            self.print_uuid = print_uuid
        if printer_serial is not None:
            self.printer_serial = printer_serial
        if platform_serial is not None:
            self.platform_serial = platform_serial
        if cassette_serial is not None:
            self.cassette_serial = cassette_serial
        if resin_lot_number is not None:
            self.resin_lot_number = resin_lot_number
        if started_at is not None:
            self.started_at = started_at
        if finished_at is not None:
            self.finished_at = finished_at
        if error is not None:
            self.error = error

    @property
    def queued_at(self):
        """Gets the queued_at of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The queued_at of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._queued_at

    @queued_at.setter
    def queued_at(self, queued_at):
        """Sets the queued_at of this PartGenealogyPrintInfo.


        :param queued_at: The queued_at of this PartGenealogyPrintInfo.  # noqa: E501
        :type: datetime
        """

        self._queued_at = queued_at

    @property
    def print_uuid(self):
        """Gets the print_uuid of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The print_uuid of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: str
        """
        return self._print_uuid

    @print_uuid.setter
    def print_uuid(self, print_uuid):
        """Sets the print_uuid of this PartGenealogyPrintInfo.


        :param print_uuid: The print_uuid of this PartGenealogyPrintInfo.  # noqa: E501
        :type: str
        """

        self._print_uuid = print_uuid

    @property
    def printer_serial(self):
        """Gets the printer_serial of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The printer_serial of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: str
        """
        return self._printer_serial

    @printer_serial.setter
    def printer_serial(self, printer_serial):
        """Sets the printer_serial of this PartGenealogyPrintInfo.


        :param printer_serial: The printer_serial of this PartGenealogyPrintInfo.  # noqa: E501
        :type: str
        """

        self._printer_serial = printer_serial

    @property
    def platform_serial(self):
        """Gets the platform_serial of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The platform_serial of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: str
        """
        return self._platform_serial

    @platform_serial.setter
    def platform_serial(self, platform_serial):
        """Sets the platform_serial of this PartGenealogyPrintInfo.


        :param platform_serial: The platform_serial of this PartGenealogyPrintInfo.  # noqa: E501
        :type: str
        """

        self._platform_serial = platform_serial

    @property
    def cassette_serial(self):
        """Gets the cassette_serial of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The cassette_serial of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: str
        """
        return self._cassette_serial

    @cassette_serial.setter
    def cassette_serial(self, cassette_serial):
        """Sets the cassette_serial of this PartGenealogyPrintInfo.


        :param cassette_serial: The cassette_serial of this PartGenealogyPrintInfo.  # noqa: E501
        :type: str
        """

        self._cassette_serial = cassette_serial

    @property
    def resin_lot_number(self):
        """Gets the resin_lot_number of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The resin_lot_number of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: str
        """
        return self._resin_lot_number

    @resin_lot_number.setter
    def resin_lot_number(self, resin_lot_number):
        """Sets the resin_lot_number of this PartGenealogyPrintInfo.


        :param resin_lot_number: The resin_lot_number of this PartGenealogyPrintInfo.  # noqa: E501
        :type: str
        """

        self._resin_lot_number = resin_lot_number

    @property
    def started_at(self):
        """Gets the started_at of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The started_at of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this PartGenealogyPrintInfo.


        :param started_at: The started_at of this PartGenealogyPrintInfo.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def finished_at(self):
        """Gets the finished_at of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The finished_at of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this PartGenealogyPrintInfo.


        :param finished_at: The finished_at of this PartGenealogyPrintInfo.  # noqa: E501
        :type: datetime
        """

        self._finished_at = finished_at

    @property
    def error(self):
        """Gets the error of this PartGenealogyPrintInfo.  # noqa: E501


        :return: The error of this PartGenealogyPrintInfo.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this PartGenealogyPrintInfo.


        :param error: The error of this PartGenealogyPrintInfo.  # noqa: E501
        :type: str
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartGenealogyPrintInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartGenealogyPrintInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.part_measurement_template_response import PartMeasurementTemplateResponse  # noqa: E501
from carbon3d.rest import ApiException

class TestPartMeasurementTemplateResponse(unittest.TestCase):
    """PartMeasurementTemplateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PartMeasurementTemplateResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.part_measurement_template_response.PartMeasurementTemplateResponse()  # noqa: E501
        if include_optional :
            return PartMeasurementTemplateResponse(
                limit = 56, 
                next_cursor = 'dXNlcjpXMDdRQ1JQQTQ=', 
                total_count = 56, 
                part_measurement_templates = [
                    {"uuid":"c13fcaeb-b106-4126-9ca6-3ecbb0ba3124","updated_at":"2020-03-28T12:25:00.000Z","production_sop_name":"Helmet Pad Size 56","production_sop_version":5,"operation_name":"WASH","measurement_name":"Visual Inspection","zones":["A","B","C","D"],"zones_enabled":true,"required_level":"required_for_failure","measurement_type":"category","measurement_classification":"visual","units":null,"min":null,"max":null,"category_options":{"fail":["Adhesion","Fringing","Tear"],"flag":[],"pass":["Pass"]}}
                    ]
            )
        else :
            return PartMeasurementTemplateResponse(
        )

    def testPartMeasurementTemplateResponse(self):
        """Test PartMeasurementTemplateResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from carbon3d.api.attachments_api import AttachmentsApi
from carbon3d.api.builds_api import BuildsApi
from carbon3d.api.models_api import ModelsApi
from carbon3d.api.orders_api import OrdersApi
from carbon3d.api.part_measurement_templates_api import PartMeasurementTemplatesApi
from carbon3d.api.part_measurements_api import PartMeasurementsApi
from carbon3d.api.part_orders_api import PartOrdersApi
from carbon3d.api.parts_api import PartsApi
from carbon3d.api.print_orders_api import PrintOrdersApi
from carbon3d.api.printed_parts_api import PrintedPartsApi
from carbon3d.api.printers_api import PrintersApi
from carbon3d.api.prints_api import PrintsApi



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PartGenealogyBuildInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'build_uuid': 'str',
        'traveler_url': 'str',
        'slice_video_url': 'str',
        'error': 'str'
    }

    attribute_map = {
        'build_uuid': 'build_uuid',
        'traveler_url': 'traveler_url',
        'slice_video_url': 'slice_video_url',
        'error': 'error'
    }

    def __init__(self, build_uuid=None, traveler_url=None, slice_video_url=None, error=None, local_vars_configuration=None):  # noqa: E501
        """PartGenealogyBuildInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._build_uuid = None
        self._traveler_url = None
        self._slice_video_url = None
        self._error = None
        self.discriminator = None

        if build_uuid is not None:
            self.build_uuid = build_uuid
        if traveler_url is not None:
            self.traveler_url = traveler_url
        if slice_video_url is not None:
            self.slice_video_url = slice_video_url
        if error is not None:
            self.error = error

    @property
    def build_uuid(self):
        """Gets the build_uuid of this PartGenealogyBuildInfo.  # noqa: E501


        :return: The build_uuid of this PartGenealogyBuildInfo.  # noqa: E501
        :rtype: str
        """
        return self._build_uuid

    @build_uuid.setter
    def build_uuid(self, build_uuid):
        """Sets the build_uuid of this PartGenealogyBuildInfo.


        :param build_uuid: The build_uuid of this PartGenealogyBuildInfo.  # noqa: E501
        :type: str
        """

        self._build_uuid = build_uuid

    @property
    def traveler_url(self):
        """Gets the traveler_url of this PartGenealogyBuildInfo.  # noqa: E501


        :return: The traveler_url of this PartGenealogyBuildInfo.  # noqa: E501
        :rtype: str
        """
        return self._traveler_url

    @traveler_url.setter
    def traveler_url(self, traveler_url):
        """Sets the traveler_url of this PartGenealogyBuildInfo.


        :param traveler_url: The traveler_url of this PartGenealogyBuildInfo.  # noqa: E501
        :type: str
        """

        self._traveler_url = traveler_url

    @property
    def slice_video_url(self):
        """Gets the slice_video_url of this PartGenealogyBuildInfo.  # noqa: E501


        :return: The slice_video_url of this PartGenealogyBuildInfo.  # noqa: E501
        :rtype: str
        """
        return self._slice_video_url

    @slice_video_url.setter
    def slice_video_url(self, slice_video_url):
        """Sets the slice_video_url of this PartGenealogyBuildInfo.


        :param slice_video_url: The slice_video_url of this PartGenealogyBuildInfo.  # noqa: E501
        :type: str
        """

        self._slice_video_url = slice_video_url

    @property
    def error(self):
        """Gets the error of this PartGenealogyBuildInfo.  # noqa: E501


        :return: The error of this PartGenealogyBuildInfo.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this PartGenealogyBuildInfo.


        :param error: The error of this PartGenealogyBuildInfo.  # noqa: E501
        :type: str
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartGenealogyBuildInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartGenealogyBuildInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class Order(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'status': 'PartOrderStatus',
        'order_number': 'str',
        'due_date': 'datetime',
        'route_to': 'list[str]',
        'printed_parts': 'list[PrintedPartRef]',
        'flushed_at': 'datetime'
    }

    attribute_map = {
        'uuid': 'uuid',
        'status': 'status',
        'order_number': 'order_number',
        'due_date': 'due_date',
        'route_to': 'route_to',
        'printed_parts': 'printed_parts',
        'flushed_at': 'flushed_at'
    }

    def __init__(self, uuid=None, status=None, order_number=None, due_date=None, route_to=None, printed_parts=None, flushed_at=None, local_vars_configuration=None):  # noqa: E501
        """Order - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._status = None
        self._order_number = None
        self._due_date = None
        self._route_to = None
        self._printed_parts = None
        self._flushed_at = None
        self.discriminator = None

        self.uuid = uuid
        if status is not None:
            self.status = status
        self.order_number = order_number
        self.due_date = due_date
        if route_to is not None:
            self.route_to = route_to
        self.printed_parts = printed_parts
        if flushed_at is not None:
            self.flushed_at = flushed_at

    @property
    def uuid(self):
        """Gets the uuid of this Order.  # noqa: E501

        Order UUID  # noqa: E501

        :return: The uuid of this Order.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this Order.

        Order UUID  # noqa: E501

        :param uuid: The uuid of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and uuid is None:  # noqa: E501
            raise ValueError("Invalid value for `uuid`, must not be `None`")  # noqa: E501

        self._uuid = uuid

    @property
    def status(self):
        """Gets the status of this Order.  # noqa: E501


        :return: The status of this Order.  # noqa: E501
        :rtype: PartOrderStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Order.


        :param status: The status of this Order.  # noqa: E501
        :type: PartOrderStatus
        """

        self._status = status

    @property
    def order_number(self):
        """Gets the order_number of this Order.  # noqa: E501

        Customer-provided order number  # noqa: E501

        :return: The order_number of this Order.  # noqa: E501
        :rtype: str
        """
        return self._order_number

    @order_number.setter
    def order_number(self, order_number):
        """Sets the order_number of this Order.

        Customer-provided order number  # noqa: E501

        :param order_number: The order_number of this Order.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_number is None:  # noqa: E501
            raise ValueError("Invalid value for `order_number`, must not be `None`")  # noqa: E501

        self._order_number = order_number

    @property
    def due_date(self):
        """Gets the due_date of this Order.  # noqa: E501

        Print due date, used to prioritize orders for packing and printing  # noqa: E501

        :return: The due_date of this Order.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this Order.

        Print due date, used to prioritize orders for packing and printing  # noqa: E501

        :param due_date: The due_date of this Order.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and due_date is None:  # noqa: E501
            raise ValueError("Invalid value for `due_date`, must not be `None`")  # noqa: E501

        self._due_date = due_date

    @property
    def route_to(self):
        """Gets the route_to of this Order.  # noqa: E501

        Section to route this order to (e.g. a rework line)  # noqa: E501

        :return: The route_to of this Order.  # noqa: E501
        :rtype: list[str]
        """
        return self._route_to

    @route_to.setter
    def route_to(self, route_to):
        """Sets the route_to of this Order.

        Section to route this order to (e.g. a rework line)  # noqa: E501

        :param route_to: The route_to of this Order.  # noqa: E501
        :type: list[str]
        """

        self._route_to = route_to

    @property
    def printed_parts(self):
        """Gets the printed_parts of this Order.  # noqa: E501

        Parts already printed or to be printed  # noqa: E501

        :return: The printed_parts of this Order.  # noqa: E501
        :rtype: list[PrintedPartRef]
        """
        return self._printed_parts

    @printed_parts.setter
    def printed_parts(self, printed_parts):
        """Sets the printed_parts of this Order.

        Parts already printed or to be printed  # noqa: E501

        :param printed_parts: The printed_parts of this Order.  # noqa: E501
        :type: list[PrintedPartRef]
        """
        if self.local_vars_configuration.client_side_validation and printed_parts is None:  # noqa: E501
            raise ValueError("Invalid value for `printed_parts`, must not be `None`")  # noqa: E501

        self._printed_parts = printed_parts

    @property
    def flushed_at(self):
        """Gets the flushed_at of this Order.  # noqa: E501

        When the order was flushed, or null if it has not been flushed  # noqa: E501

        :return: The flushed_at of this Order.  # noqa: E501
        :rtype: datetime
        """
        return self._flushed_at

    @flushed_at.setter
    def flushed_at(self, flushed_at):
        """Sets the flushed_at of this Order.

        When the order was flushed, or null if it has not been flushed  # noqa: E501

        :param flushed_at: The flushed_at of this Order.  # noqa: E501
        :type: datetime
        """

        self._flushed_at = flushed_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Order):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Order):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class ModelPrint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'print_id': 'str',
        'build_uuid': 'str',
        'finished_at': 'datetime',
        'started_at': 'datetime',
        'remaining_sec': 'int',
        'printed_by': 'str',
        'print_order_uuid': 'str',
        'print_order_number': 'str',
        'status': 'str',
        'origin': 'PrintOrigin',
        'config': 'PrintConfig',
        'metrics': 'PrintMetrics',
        'feedback': 'PrintFeedback'
    }

    attribute_map = {
        'name': 'name',
        'print_id': 'print_id',
        'build_uuid': 'build_uuid',
        'finished_at': 'finished_at',
        'started_at': 'started_at',
        'remaining_sec': 'remaining_sec',
        'printed_by': 'printed_by',
        'print_order_uuid': 'print_order_uuid',
        'print_order_number': 'print_order_number',
        'status': 'status',
        'origin': 'origin',
        'config': 'config',
        'metrics': 'metrics',
        'feedback': 'feedback'
    }

    def __init__(self, name=None, print_id=None, build_uuid=None, finished_at=None, started_at=None, remaining_sec=None, printed_by=None, print_order_uuid=None, print_order_number=None, status=None, origin=None, config=None, metrics=None, feedback=None, local_vars_configuration=None):  # noqa: E501
        """ModelPrint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._print_id = None
        self._build_uuid = None
        self._finished_at = None
        self._started_at = None
        self._remaining_sec = None
        self._printed_by = None
        self._print_order_uuid = None
        self._print_order_number = None
        self._status = None
        self._origin = None
        self._config = None
        self._metrics = None
        self._feedback = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if print_id is not None:
            self.print_id = print_id
        if build_uuid is not None:
            self.build_uuid = build_uuid
        if finished_at is not None:
            self.finished_at = finished_at
        if started_at is not None:
            self.started_at = started_at
        if remaining_sec is not None:
            self.remaining_sec = remaining_sec
        if printed_by is not None:
            self.printed_by = printed_by
        if print_order_uuid is not None:
            self.print_order_uuid = print_order_uuid
        if print_order_number is not None:
            self.print_order_number = print_order_number
        if status is not None:
            self.status = status
        if origin is not None:
            self.origin = origin
        if config is not None:
            self.config = config
        if metrics is not None:
            self.metrics = metrics
        if feedback is not None:
            self.feedback = feedback

    @property
    def name(self):
        """Gets the name of this ModelPrint.  # noqa: E501


        :return: The name of this ModelPrint.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ModelPrint.


        :param name: The name of this ModelPrint.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def print_id(self):
        """Gets the print_id of this ModelPrint.  # noqa: E501


        :return: The print_id of this ModelPrint.  # noqa: E501
        :rtype: str
        """
        return self._print_id

    @print_id.setter
    def print_id(self, print_id):
        """Sets the print_id of this ModelPrint.


        :param print_id: The print_id of this ModelPrint.  # noqa: E501
        :type: str
        """

        self._print_id = print_id

    @property
    def build_uuid(self):
        """Gets the build_uuid of this ModelPrint.  # noqa: E501


        :return: The build_uuid of this ModelPrint.  # noqa: E501
        :rtype: str
        """
        return self._build_uuid

    @build_uuid.setter
    def build_uuid(self, build_uuid):
        """Sets the build_uuid of this ModelPrint.


        :param build_uuid: The build_uuid of this ModelPrint.  # noqa: E501
        :type: str
        """

        self._build_uuid = build_uuid

    @property
    def finished_at(self):
        """Gets the finished_at of this ModelPrint.  # noqa: E501


        :return: The finished_at of this ModelPrint.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this ModelPrint.


        :param finished_at: The finished_at of this ModelPrint.  # noqa: E501
        :type: datetime
        """

        self._finished_at = finished_at

    @property
    def started_at(self):
        """Gets the started_at of this ModelPrint.  # noqa: E501


        :return: The started_at of this ModelPrint.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this ModelPrint.


        :param started_at: The started_at of this ModelPrint.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def remaining_sec(self):
        """Gets the remaining_sec of this ModelPrint.  # noqa: E501

        Estimated time until expected print completion (in seconds)  # noqa: E501

        :return: The remaining_sec of this ModelPrint.  # noqa: E501
        :rtype: int
        """
        return self._remaining_sec

    @remaining_sec.setter
    def remaining_sec(self, remaining_sec):
        """Sets the remaining_sec of this ModelPrint.

        Estimated time until expected print completion (in seconds)  # noqa: E501

        :param remaining_sec: The remaining_sec of this ModelPrint.  # noqa: E501
        :type: int
        """

        self._remaining_sec = remaining_sec

    @property
    def printed_by(self):
        """Gets the printed_by of this ModelPrint.  # noqa: E501


        :return: The printed_by of this ModelPrint.  # noqa: E501
        :rtype: str
        """
        return self._printed_by

    @printed_by.setter
    def printed_by(self, printed_by):
        """Sets the printed_by of this ModelPrint.


        :param printed_by: The printed_by of this ModelPrint.  # noqa: E501
        :type: str
        """

        self._printed_by = printed_by

    @property
    def print_order_uuid(self):
        """Gets the print_order_uuid of this ModelPrint.  # noqa: E501


        :return: The print_order_uuid of this ModelPrint.  # noqa: E501
        :rtype: str
        """
        return self._print_order_uuid

    @print_order_uuid.setter
    def print_order_uuid(self, print_order_uuid):
        """Sets the print_order_uuid of this ModelPrint.


        :param print_order_uuid: The print_order_uuid of this ModelPrint.  # noqa: E501
        :type: str
        """

        self._print_order_uuid = print_order_uuid

    @property
    def print_order_number(self):
        """Gets the print_order_number of this ModelPrint.  # noqa: E501


        :return: The print_order_number of this ModelPrint.  # noqa: E501
        :rtype: str
        """
        return self._print_order_number

    @print_order_number.setter
    def print_order_number(self, print_order_number):
        """Sets the print_order_number of this ModelPrint.


        :param print_order_number: The print_order_number of this ModelPrint.  # noqa: E501
        :type: str
        """

        self._print_order_number = print_order_number

    @property
    def status(self):
        """Gets the status of this ModelPrint.  # noqa: E501


        :return: The status of this ModelPrint.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ModelPrint.


        :param status: The status of this ModelPrint.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def origin(self):
        """Gets the origin of this ModelPrint.  # noqa: E501


        :return: The origin of this ModelPrint.  # noqa: E501
        :rtype: PrintOrigin
        """
        return self._origin

    @origin.setter
    def origin(self, origin):
        """Sets the origin of this ModelPrint.


        :param origin: The origin of this ModelPrint.  # noqa: E501
        :type: PrintOrigin
        """

        self._origin = origin

    @property
    def config(self):
        """Gets the config of this ModelPrint.  # noqa: E501


        :return: The config of this ModelPrint.  # noqa: E501
        :rtype: PrintConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this ModelPrint.


        :param config: The config of this ModelPrint.  # noqa: E501
        :type: PrintConfig
        """

        self._config = config

    @property
    def metrics(self):
        """Gets the metrics of this ModelPrint.  # noqa: E501


        :return: The metrics of this ModelPrint.  # noqa: E501
        :rtype: PrintMetrics
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this ModelPrint.


        :param metrics: The metrics of this ModelPrint.  # noqa: E501
        :type: PrintMetrics
        """

        self._metrics = metrics

    @property
    def feedback(self):
        """Gets the feedback of this ModelPrint.  # noqa: E501


        :return: The feedback of this ModelPrint.  # noqa: E501
        :rtype: PrintFeedback
        """
        return self._feedback

    @feedback.setter
    def feedback(self, feedback):
        """Sets the feedback of this ModelPrint.


        :param feedback: The feedback of this ModelPrint.  # noqa: E501
        :type: PrintFeedback
        """

        self._feedback = feedback

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelPrint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelPrint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrinterStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alerts': 'list[str]',
        'printer_state': 'str',
        'software_version': 'str'
    }

    attribute_map = {
        'alerts': 'alerts',
        'printer_state': 'printer_state',
        'software_version': 'software_version'
    }

    def __init__(self, alerts=None, printer_state=None, software_version=None, local_vars_configuration=None):  # noqa: E501
        """PrinterStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alerts = None
        self._printer_state = None
        self._software_version = None
        self.discriminator = None

        if alerts is not None:
            self.alerts = alerts
        self.printer_state = printer_state
        self.software_version = software_version

    @property
    def alerts(self):
        """Gets the alerts of this PrinterStatus.  # noqa: E501


        :return: The alerts of this PrinterStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._alerts

    @alerts.setter
    def alerts(self, alerts):
        """Sets the alerts of this PrinterStatus.


        :param alerts: The alerts of this PrinterStatus.  # noqa: E501
        :type: list[str]
        """

        self._alerts = alerts

    @property
    def printer_state(self):
        """Gets the printer_state of this PrinterStatus.  # noqa: E501


        :return: The printer_state of this PrinterStatus.  # noqa: E501
        :rtype: str
        """
        return self._printer_state

    @printer_state.setter
    def printer_state(self, printer_state):
        """Sets the printer_state of this PrinterStatus.


        :param printer_state: The printer_state of this PrinterStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and printer_state is None:  # noqa: E501
            raise ValueError("Invalid value for `printer_state`, must not be `None`")  # noqa: E501

        self._printer_state = printer_state

    @property
    def software_version(self):
        """Gets the software_version of this PrinterStatus.  # noqa: E501


        :return: The software_version of this PrinterStatus.  # noqa: E501
        :rtype: str
        """
        return self._software_version

    @software_version.setter
    def software_version(self, software_version):
        """Sets the software_version of this PrinterStatus.


        :param software_version: The software_version of this PrinterStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and software_version is None:  # noqa: E501
            raise ValueError("Invalid value for `software_version`, must not be `None`")  # noqa: E501

        self._software_version = software_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrinterStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrinterStatus):
            return True

        return self.to_dict() != other.to_dict()
